/* $Workfile: Dsp55AudioVolumeIo.h $   $Revision: 1 $    $Modtime: 3/12/08 3:16p $  */
#ifndef DSP55_AUDIOVOLUME_IO_H
#define DSP55_AUDIOVOLUME_IO_H
/*--------------------------------------------------------------------------*\

  Odin TeleSystems Inc.

  SAA-1007-1 OTX DSP C5000 Software Development Kit (SDK)

  IOCLT Codes and Structs for communication between the DSP code and the
  DSP55AUDIOVOLUME user application

\*--------------------------------------------------------------------------*/


/*******************************************************************************
  @devnote
   DSP IOCTL codes.
*******************************************************************************/


#define AV_IOCTL_GET_SAMPLE         0x0101  // Mainly for debugging
#define AV_IOCTL_GET_DEBUG_DATA     0x0102  // Mainly for debugging
#define AV_IOCTL_STREAM_RX_DATA     0x0103  // Mainly for debugging
#define AV_IOCTL_SET_VOLUME         0x0104
#define AV_IOCTL_SET_LAW            0x0105
#define AV_IOCTL_SET_TS             0x0106
#define AV_IOCTL_GET_FULL_RX_FRAME  0x0107  // Mainly for debugging
#define AV_IOCTL_GET_FULL_RX_FRAME2 0x0108  // Mainly for debugging
#define AV_IOCTL_GET_FULL_TX_FRAME2 0x0109  // Mainly for debugging

/*******************************************************************************
  @devnote
   DSP Notify Event codes.
*******************************************************************************/

#define AV_NOTIFY_DEBUG_DATA       0x0200
#define AV_NOTIFY_STREAM_RX_DATA   0x0201

/*******************************************************************************
  @devnote
   Structs for passing data over the DSP IOCTL interface
*******************************************************************************/


// Fix packing for IO Control Structs
// Fix packing for IO Control Structs
#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#elif defined(__TMS320C55X__)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option push -a2
#else
#pragma pack(push,2)
#endif

// Structs used in calls to OtxDspIoControl()

typedef struct AudioVolumeIoInSetVolumeS  // Set volume for all output channels
{
  short        sqCodec[4];     // Codec 0 
} AudioVolumeIoInSetVolumeS;

typedef struct AudioVolumeIoInSetTsS  // Set volume for one channels
{
  short        nCodec;     // Codec channel
  short        nTs;        // Timeslot (0-31)
} AudioVolumeIoInSetTsS;

typedef struct AudioVolumeIoInSetLawS  // Set companding law
{
  short law;
} AudioVolumeIoInSetLawS;


typedef struct AudioVolumeIoInStreamRxDataS
{
  short        bStreamRxData;
} AudioVolumeIoInStreamRxDataS;

typedef struct AudioVolumeIoOutGetSampleS
{
  unsigned short        nResult;
  unsigned short        nDataSample;
} AudioVolumeIoOutGetSampleS;

typedef struct AudioVolumeIoOutGetFullFrameS
{
  unsigned short        nResult;
  unsigned short        nFrame[128];
} AudioVolumeIoOutGetFullFrameS;

// Structs used for Notify Events
typedef struct AudioVolumeNotifyGetDebugDataS
{
  unsigned short        nData0;
  unsigned short        nData1;
  unsigned short        nData2;
  unsigned short        nData3;
  unsigned short        nData4;
  unsigned short        nData5;
  unsigned short        nData6;
  unsigned short        nData7;
} AudioVolumeNotifyGetDebugDataS;

typedef struct AudioVolumeNotifyStreamRxDataS
{
  unsigned short        nData[25/* *16 */];
} AudioVolumeNotifyStreamRxDataS;


#if defined(__linux__) 
#pragma pack(2)
#elif defined(_TMS320C5XX)
// No pack pragma needed for the DSP compiler
#elif defined(__TMS320C55X__)
// No pack pragma needed for the DSP compiler
#elif defined(__BORLANDC__)
#pragma option pop
#else
#pragma pack(pop)
#endif


#endif  // DSP55_AUDIOVOLUME_IO_H
